==> ejc-settlementmanage-impl-3.0.0-20220425.073851-9-sources.jar: com/ejianc/business/settlementmanage/bean/DesignSettlementDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计类结算单子表-设计工程量验收、核算清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_design_settlement_detail")
public class DesignSettlementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表关联键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="project_characteristics")
    private java.lang.String projectCharacteristics; // 项目特征
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="declare_complete_num")
    private java.lang.Long declareCompleteNum; // 完成量(申报)
    @TableField(value="declare_extax_addition")
    private java.math.BigDecimal declareExtaxAddition; // 除税单价(申报)
    @TableField(value="declare_intax_addition")
    private java.math.BigDecimal declareIntaxAddition; // 含税单价(申报)
    @TableField(value="declare_extax_amount")
    private java.math.BigDecimal declareExtaxAmount; // 除税合价(申报)
    @TableField(value="declare_intax_amount")
    private java.math.BigDecimal declareIntaxAmount; // 含税合价(申报)
    @TableField(value="audit_complete_num")
    private java.lang.Long auditCompleteNum; // 完成量(审核)
    @TableField(value="audit_extax_addition")
    private java.math.BigDecimal auditExtaxAddition; // 除税单价(审核)
    @TableField(value="audit_intax_addition")
    private java.math.BigDecimal auditIntaxAddition; // 含税单价(审核)
    @TableField(value="audit_extax_amount")
    private java.math.BigDecimal auditExtaxAmount; // 除税合价(审核)
    @TableField(value="audit_intax_amount")
    private java.math.BigDecimal auditIntaxAmount; // 含税合价(审核)
    @TableField(value="categorys")
    private java.lang.String categorys; // 类别
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 项目特征
     */
    public java.lang.String getProjectCharacteristics() {
        return projectCharacteristics;
    }

    /**
     * 项目特征
     */
    public void setProjectCharacteristics(java.lang.String projectCharacteristics) {
        this.projectCharacteristics = projectCharacteristics;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量(申报)
     */
    public java.lang.Long getDeclareCompleteNum() {
        return declareCompleteNum;
    }

    /**
     * 完成量(申报)
     */
    public void setDeclareCompleteNum(java.lang.Long declareCompleteNum) {
        this.declareCompleteNum = declareCompleteNum;
    }
    /**
     * 除税单价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAddition() {
        return declareExtaxAddition;
    }

    /**
     * 除税单价(申报)
     */
    public void setDeclareExtaxAddition(java.math.BigDecimal declareExtaxAddition) {
        this.declareExtaxAddition = declareExtaxAddition;
    }
    /**
     * 含税单价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAddition() {
        return declareIntaxAddition;
    }

    /**
     * 含税单价(申报)
     */
    public void setDeclareIntaxAddition(java.math.BigDecimal declareIntaxAddition) {
        this.declareIntaxAddition = declareIntaxAddition;
    }
    /**
     * 除税合价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAmount() {
        return declareExtaxAmount;
    }

    /**
     * 除税合价(申报)
     */
    public void setDeclareExtaxAmount(java.math.BigDecimal declareExtaxAmount) {
        this.declareExtaxAmount = declareExtaxAmount;
    }
    /**
     * 含税合价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAmount() {
        return declareIntaxAmount;
    }

    /**
     * 含税合价(申报)
     */
    public void setDeclareIntaxAmount(java.math.BigDecimal declareIntaxAmount) {
        this.declareIntaxAmount = declareIntaxAmount;
    }
    /**
     * 完成量(审核)
     */
    public java.lang.Long getAuditCompleteNum() {
        return auditCompleteNum;
    }

    /**
     * 完成量(审核)
     */
    public void setAuditCompleteNum(java.lang.Long auditCompleteNum) {
        this.auditCompleteNum = auditCompleteNum;
    }
    /**
     * 除税单价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAddition() {
        return auditExtaxAddition;
    }

    /**
     * 除税单价(审核)
     */
    public void setAuditExtaxAddition(java.math.BigDecimal auditExtaxAddition) {
        this.auditExtaxAddition = auditExtaxAddition;
    }
    /**
     * 含税单价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAddition() {
        return auditIntaxAddition;
    }

    /**
     * 含税单价(审核)
     */
    public void setAuditIntaxAddition(java.math.BigDecimal auditIntaxAddition) {
        this.auditIntaxAddition = auditIntaxAddition;
    }
    /**
     * 除税合价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAmount() {
        return auditExtaxAmount;
    }

    /**
     * 除税合价(审核)
     */
    public void setAuditExtaxAmount(java.math.BigDecimal auditExtaxAmount) {
        this.auditExtaxAmount = auditExtaxAmount;
    }
    /**
     * 含税合价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAmount() {
        return auditIntaxAmount;
    }

    /**
     * 含税合价(审核)
     */
    public void setAuditIntaxAmount(java.math.BigDecimal auditIntaxAmount) {
        this.auditIntaxAmount = auditIntaxAmount;
    }
    /**
     * 类别
     */
    public java.lang.String getCategorys() {
        return categorys;
    }

    /**
     * 类别
     */
    public void setCategorys(java.lang.String categorys) {
        this.categorys = categorys;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20220902.041051-56-sources.jar: com/ejianc/business/settlementmanage/bean/DesignSettlementDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计类结算单子表-设计工程量验收、核算清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_design_settlement_detail")
public class DesignSettlementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表关联键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="project_characteristics")
    private java.lang.String projectCharacteristics; // 项目特征
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="declare_complete_num")
    private java.lang.Long declareCompleteNum; // 完成量(申报)
    @TableField(value="declare_extax_addition")
    private java.math.BigDecimal declareExtaxAddition; // 除税单价(申报)
    @TableField(value="declare_intax_addition")
    private java.math.BigDecimal declareIntaxAddition; // 含税单价(申报)
    @TableField(value="declare_extax_amount")
    private java.math.BigDecimal declareExtaxAmount; // 除税合价(申报)
    @TableField(value="declare_intax_amount")
    private java.math.BigDecimal declareIntaxAmount; // 含税合价(申报)
    @TableField(value="audit_complete_num")
    private java.lang.Long auditCompleteNum; // 完成量(审核)
    @TableField(value="audit_extax_addition")
    private java.math.BigDecimal auditExtaxAddition; // 除税单价(审核)
    @TableField(value="audit_intax_addition")
    private java.math.BigDecimal auditIntaxAddition; // 含税单价(审核)
    @TableField(value="audit_extax_amount")
    private java.math.BigDecimal auditExtaxAmount; // 除税合价(审核)
    @TableField(value="audit_intax_amount")
    private java.math.BigDecimal auditIntaxAmount; // 含税合价(审核)
    @TableField(value="categorys")
    private java.lang.String categorys; // 类别
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 项目特征
     */
    public java.lang.String getProjectCharacteristics() {
        return projectCharacteristics;
    }

    /**
     * 项目特征
     */
    public void setProjectCharacteristics(java.lang.String projectCharacteristics) {
        this.projectCharacteristics = projectCharacteristics;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量(申报)
     */
    public java.lang.Long getDeclareCompleteNum() {
        return declareCompleteNum;
    }

    /**
     * 完成量(申报)
     */
    public void setDeclareCompleteNum(java.lang.Long declareCompleteNum) {
        this.declareCompleteNum = declareCompleteNum;
    }
    /**
     * 除税单价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAddition() {
        return declareExtaxAddition;
    }

    /**
     * 除税单价(申报)
     */
    public void setDeclareExtaxAddition(java.math.BigDecimal declareExtaxAddition) {
        this.declareExtaxAddition = declareExtaxAddition;
    }
    /**
     * 含税单价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAddition() {
        return declareIntaxAddition;
    }

    /**
     * 含税单价(申报)
     */
    public void setDeclareIntaxAddition(java.math.BigDecimal declareIntaxAddition) {
        this.declareIntaxAddition = declareIntaxAddition;
    }
    /**
     * 除税合价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAmount() {
        return declareExtaxAmount;
    }

    /**
     * 除税合价(申报)
     */
    public void setDeclareExtaxAmount(java.math.BigDecimal declareExtaxAmount) {
        this.declareExtaxAmount = declareExtaxAmount;
    }
    /**
     * 含税合价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAmount() {
        return declareIntaxAmount;
    }

    /**
     * 含税合价(申报)
     */
    public void setDeclareIntaxAmount(java.math.BigDecimal declareIntaxAmount) {
        this.declareIntaxAmount = declareIntaxAmount;
    }
    /**
     * 完成量(审核)
     */
    public java.lang.Long getAuditCompleteNum() {
        return auditCompleteNum;
    }

    /**
     * 完成量(审核)
     */
    public void setAuditCompleteNum(java.lang.Long auditCompleteNum) {
        this.auditCompleteNum = auditCompleteNum;
    }
    /**
     * 除税单价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAddition() {
        return auditExtaxAddition;
    }

    /**
     * 除税单价(审核)
     */
    public void setAuditExtaxAddition(java.math.BigDecimal auditExtaxAddition) {
        this.auditExtaxAddition = auditExtaxAddition;
    }
    /**
     * 含税单价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAddition() {
        return auditIntaxAddition;
    }

    /**
     * 含税单价(审核)
     */
    public void setAuditIntaxAddition(java.math.BigDecimal auditIntaxAddition) {
        this.auditIntaxAddition = auditIntaxAddition;
    }
    /**
     * 除税合价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAmount() {
        return auditExtaxAmount;
    }

    /**
     * 除税合价(审核)
     */
    public void setAuditExtaxAmount(java.math.BigDecimal auditExtaxAmount) {
        this.auditExtaxAmount = auditExtaxAmount;
    }
    /**
     * 含税合价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAmount() {
        return auditIntaxAmount;
    }

    /**
     * 含税合价(审核)
     */
    public void setAuditIntaxAmount(java.math.BigDecimal auditIntaxAmount) {
        this.auditIntaxAmount = auditIntaxAmount;
    }
    /**
     * 类别
     */
    public java.lang.String getCategorys() {
        return categorys;
    }

    /**
     * 类别
     */
    public void setCategorys(java.lang.String categorys) {
        this.categorys = categorys;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
